@@ -416,12 +416,14 @@ class OrderManager(base.BaseEntityManager):
             raise TypeError('Unknown Order type "{0}"'.format(order_type))
 
     def create(self, type=None, **kwargs):
+        if not type:
+            raise TypeError('No Order type provided')
         order_type = self._order_type_to_class_map.get(type.lower())
-        if order_type is not None:
-            return order_type(self._api, **kwargs)
-        else:
+        if not order_type:
             raise TypeError('Unknown Order type "{0}"'.format(type))
 
+        return order_type(self._api, **kwargs)
+
     def create_key(self, name=None, algorithm=None, bit_length=None, mode=None,
                    payload_content_type=None, expiration=None):
         """
