@@ -19,6 +19,7 @@ import logging
 from oslo_utils.timeutils import parse_isotime
 import six
 
+from barbicanclient import acls as acl_manager
 from barbicanclient import base
 from barbicanclient import exceptions
 from barbicanclient import formatter
@@ -109,6 +110,8 @@ class Secret(SecretFormatter):
             status=status,
             creator_id=creator_id
         )
+        self._acl_manager = acl_manager.ACLManager(api)
+        self._acls = None
 
     @property
     def secret_ref(self):
@@ -185,9 +188,20 @@ class Secret(SecretFormatter):
         Lazy-loaded property that holds the unencrypted data
         """
         if self._payload is None and self.secret_ref is not None:
-            self._fetch_payload()
+            try:
+                self._fetch_payload()
+            except ValueError:
+                LOG.warning("Secret does not contain a payload")
+                return None
         return self._payload
 
+    @property
+    def acls(self):
+        """Get ACL settings for this secret."""
+        if self.secret_ref and not self._acls:
+            self._acls = self._acl_manager.get(self.secret_ref)
+        return self._acls
+
     @name.setter
     @immutable_after_save
     def name(self, value):
@@ -219,7 +233,6 @@ class Secret(SecretFormatter):
         self._mode = value
 
     @payload.setter
-    @immutable_after_save
     def payload(self, value):
         self._payload = value
 
@@ -279,10 +292,15 @@ class Secret(SecretFormatter):
             'expiration': self.expiration
         }
 
-        if not self.payload:
-            raise exceptions.PayloadException("Missing Payload")
-        if not isinstance(self.payload, (six.text_type, six.binary_type)):
+        if self.payload == '':
+            raise exceptions.PayloadException("Invalid Payload: "
+                                              "Cannot Be Empty String")
+
+        if self.payload is not None and not isinstance(self.payload,
+                                                       (six.text_type,
+                                                        six.binary_type)):
             raise exceptions.PayloadException("Invalid Payload Type")
+
         if self.payload_content_type or self.payload_content_encoding:
             """
             Setting the payload_content_type and payload_content_encoding
@@ -322,6 +340,27 @@ class Secret(SecretFormatter):
             self._secret_ref = response.get('secret_ref')
         return self.secret_ref
 
+    def update(self):
+        """
+        Updates the secret in Barbican.
+        """
+
+        if not self.payload:
+            raise exceptions.PayloadException("Invalid or Missing Payload")
+        if not self.secret_ref:
+            raise LookupError("Secret is not yet stored.")
+
+        if type(self.payload) is six.binary_type:
+            headers = {'content-type': "application/octet-stream"}
+        elif type(self.payload) is six.text_type:
+            headers = {'content-type': "text/plain"}
+        else:
+            raise exceptions.PayloadException("Invalid Payload Type")
+
+        self._api.put(self._secret_ref,
+                      headers=headers,
+                      data=self.payload)
+
     def delete(self):
         """
         Deletes the Secret from Barbican
@@ -426,6 +465,32 @@ class SecretManager(base.BaseEntityManager):
             secret_ref=secret_ref
         )
 
+    def update(self, secret_ref, payload=None):
+        """
+        Update an existing Secret from Barbican
+
+        :param str secret_ref: Full HATEOAS reference to a Secret
+        :param str payload: New payload to add to secret
+        :raises barbicanclient.exceptions.HTTPAuthError: 401 Responses
+        :raises barbicanclient.exceptions.HTTPClientError: 4xx Responses
+        :raises barbicanclient.exceptions.HTTPServerError: 5xx Responses
+        """
+
+        base.validate_ref(secret_ref, 'Secret')
+        if not secret_ref:
+            raise ValueError('secret_ref is required.')
+
+        if type(payload) is six.binary_type:
+            headers = {'content-type': "application/octet-stream"}
+        elif type(payload) is six.text_type:
+            headers = {'content-type': "text/plain"}
+        else:
+            raise exceptions.PayloadException("Invalid Payload Type")
+
+        self._api.put(secret_ref,
+                      headers=headers,
+                      data=payload)
+
     def create(self, name=None, payload=None,
                payload_content_type=None, payload_content_encoding=None,
                algorithm=None, bit_length=None, secret_type=None,
